@@ -23,7 +23,7 @@ LOG_FMT = (
 
 LOGGING_CONFIG = {
     "version": 1,
-    "disable_existing_loggers": True,
+    "disable_existing_loggers": False,
     "formatters": {"standard": {"format": LOG_FMT, "datefmt": "%Y-%m-%dT%H:%M:%S"}},
     "handlers": {
         "default": {
